###################################################
### chunk number 1: preliminaries
###################################################
library("dcemriS4")
## options(NIfTI.audit.trail=FALSE)
options(width=85)
require("minpack.lm")
require("bitops")


###################################################
### chunk number 2: NIfTI.audit.trail eval=FALSE
###################################################
## options(NIfTI.audit.trail=FALSE)


###################################################
### chunk number 3: avg152T1_LR_nifti
###################################################
mni.LR <- readNIfTI(system.file("nifti/avg152T1_LR_nifti.nii.gz", 
                                package="dcemriS4"))
mni.LR
audit.trail(mni.LR)
descrip(mni.LR)


###################################################
### chunk number 4: figure1-png
###################################################
png(filename="avg152T1_LR_nifti.png", width=400, height=400, bg="black")


###################################################
### chunk number 5: figure1-code
###################################################
image(mni.LR)


###################################################
### chunk number 6: figure1-dev.off
###################################################
dev.off()


###################################################
### chunk number 7: avg152T1_RL_nifti
###################################################
mni.RL <- readNIfTI(system.file("nifti/avg152T1_RL_nifti.nii.gz", 
                                package="dcemriS4"))
mni.RL


###################################################
### chunk number 8: figure2-png
###################################################
png(filename="avg152T1_RL_nifti.png", width=400, height=400, bg="black")


###################################################
### chunk number 9: figure2-code
###################################################
image(mni.RL)


###################################################
### chunk number 10: figure2-dev.off
###################################################
dev.off()


###################################################
### chunk number 11: filtered_func_data
###################################################
ffd <- readNIfTI(system.file("nifti/filtered_func_data.nii.gz", 
                             package="dcemriS4"))
ffd


###################################################
### chunk number 12: figure3-png
###################################################
png(filename="ffd.png", width=400, height=400, bg="black")


###################################################
### chunk number 13: figure3-code
###################################################
image(ffd)


###################################################
### chunk number 14: figure3-dev.off
###################################################
dev.off()


###################################################
### chunk number 15: figure3b-png
###################################################
png(filename="ffd_orthographic.png", width=400, height=400, bg="black")


###################################################
### chunk number 16: figure3b-code
###################################################
orthographic(ffd)


###################################################
### chunk number 17: figure3b-dev.off
###################################################
dev.off()


###################################################
### chunk number 18: zstat1
###################################################
zstat1 <- readNIfTI(system.file("nifti/zstat1.nii.gz", package="dcemriS4"))
zstat1


###################################################
### chunk number 19: figure4-png
###################################################
png("ffd_zstat1.png", width=400, height=400, bg="black")


###################################################
### chunk number 20: figure4-code
###################################################
overlay(ffd, ifelse(abs(zstat1) > 5, zstat1, NA), zlim.y=range(zstat1))


###################################################
### chunk number 21: figure4-dev.off
###################################################
dev.off()


###################################################
### chunk number 22: doubleanglemethod
###################################################
sdam60 <- readNIfTI(system.file("nifti/SDAM_ep2d_60deg_26slc.nii.gz", 
                                package="dcemriS4"))
sdam60
sdam120 <- readNIfTI(system.file("nifti/SDAM_ep2d_120deg_26slc.nii.gz", 
                                 package="dcemriS4"))
sdam120
sdam.image <- rowMeans(dam(sdam60, sdam120, 60), dims=3)
mask <- (rowSums(sdam60, dims=3) > 500) # nifti(rowSums(sdam60, dims=3) > 500)


###################################################
### chunk number 23: figure5-png
###################################################
png("sdam.png", width=400, height=400)


###################################################
### chunk number 24: figure5-code
###################################################
# A smooth version of "sdam.image"
SDAM <- readNIfTI(system.file("nifti/SDAM_smooth.nii.gz", package="dcemriS4"))
overlay(sdam120, ifelse(mask, SDAM, NA), z=13, zlim.x=range(sdam120), 
        zlim.y=c(0.5,1.5), plot.type="single")


###################################################
### chunk number 25: figure5-dev.off
###################################################
dev.off()


###################################################
### chunk number 26: t1estimation
###################################################
fnames <- c("fl3d_vibe-5deg","fl3d_vibe-10deg","fl3d_vibe-20deg",
            "fl3d_vibe-25deg","fl3d_vibe-15deg")
alpha <- c(5, 10, 20, 25, 15)
nangles <- length(alpha)
X <- Y <- 64
Z <- 36
flip <- fangles <- array(0, c(X,Y,Z,nangles))
for (w in 1:nangles) {
  vibe <- readNIfTI(system.file(paste("nifti/", fnames[w], ".nii.gz", sep=""), 
                                package="dcemriS4"))
  flip[,,1:nsli(vibe),w] <- vibe
  fangles[,,,w] <- array(alpha[w], c(X,Y,Z))
}
TR <- 4.22 / 1000 # seconds
fanglesB1 <- fangles * array(SDAM, c(X,Y,Z,nangles))
zi <- 10:13
maskzi <- mask
maskzi[,,(! 1:Z %in% zi)] <- FALSE
R1 <- R1.fast(flip, maskzi, fanglesB1, TR, verbose=TRUE)


###################################################
### chunk number 27: figure6-png
###################################################
png("t1_phantom.png", width=400, height=400)


###################################################
### chunk number 28: figure6-code
###################################################
overlay(vibe, 1/R1$R10[,,1:nsli(vibe),], z=13, zlim.x=c(0,1024), 
        zlim.y=c(0,2.5), plot.type="single")


###################################################
### chunk number 29: figure6-dev.off
###################################################
dev.off()


###################################################
### chunk number 30: FSLmask
###################################################
t1pmask <- readNIfTI(system.file("nifti/t1_phantom_mask.nii.gz", 
                                 package="dcemriS4"))
pmask <- nifti(array(t1pmask[,,25], dim(t1pmask))) # repeat slice #25
pmask


###################################################
### chunk number 31: figure7
###################################################
T1 <- c(.484,.350,1.07,.648,.456,1.07,.660,1.543,1.543,.353)
par(mfrow=c(1,1), mar=c(5,4,4,2)+.1)
boxplot(split(1/drop(R1$R10), as.factor(drop(pmask)))[-1], 
        ylim=c(0,2.5), xlab="Region of Interest", ylab="T1 (seconds)")
points(1:10, T1, col=rainbow(10), pch=16, cex=2)


###################################################
### chunk number 32: buckley.aif
###################################################
data("buckley")
aifparams <- with(buckley, orton.exp.lm(time.min, input))
fit.aif <- with(aifparams, aif.orton.exp(buckley$time.min, AB, muB, AG, muG))


###################################################
### chunk number 33: figure8
###################################################
with(buckley, plot(time.min, input, type="l", lwd=2, xlab="Time (minutes)", 
                   ylab=""))
with(buckley, lines(time.min, fit.aif, lwd=2, col=2))
legend("topright", c("Simulated AIF", "Estimated AIF"), lwd=2, col=1:2)


###################################################
### chunk number 34: buckley.kinetic
###################################################
xi <- seq(5, 300, by=5)
img <- array(t(breast$data)[,xi], c(13,1,1,60))
time <- buckley$time.min[xi]
aif <- buckley$input[xi]
mask <- array(TRUE, dim(img)[1:3])
aifparams <- orton.exp.lm(time, aif)
fit <- dcemri.lm(img, time, mask, model="orton.exp",
                 aif="user", user=aifparams)


###################################################
### chunk number 35: figure9
###################################################
par(mfrow=c(4,4), mar=c(5,4,4,2)/1.25, mex=0.8)
for (x in 1:nrow(img)) {
  plot(time, img[x,1,1,], ylim=range(img), xlab="Time (minutes)",
       ylab="", main=paste("Series", x))
  kinparams <- with(fit, c(vp[x,1,1], ktrans[x,1,1], kep[x,1,1]))
  lines(time, model.orton.exp(time, aifparams[1:4], kinparams), 
        lwd=1.5, col=2)
}


